@@ -7,13 +7,11 @@ RESTFUL_HEADER = {
 HTTP_API_KEY = 'HTTP_API_KEY'
 HTTP_USER_TOKEN = 'HTTP_USER_TOKEN'
 HTTP_FROM = 'HTTP_X_FORWARDED_FOR'
-CSRF_COOKIE_USED = 'CSRF_COOKIE_USED'
 
 # Header names from response
 USER_TOKEN = 'user-token'
 API_KEY = 'api-key'
 CLIENT_IP = 'client-ip'
-CSRF_TOKEN = 'X-CSRFToken'
 
 # Response content
 MESSAGE = 'message'
